]> sigrok.org Git - libsigrok.git/blobdiff - session.c
sr: s/sr_session_bus/sr_session_send/.
[libsigrok.git] / session.c
index 2c066f9454553ac757f30ab6115fc3c7b728afa9..06d4a3b4f68bdfec6d10616632f663bb0f597f2e 100644 (file)
--- a/session.c
+++ b/session.c
@@ -32,7 +32,7 @@ struct source {
        int fd;
        int events;
        int timeout;
-       sr_receive_data_callback cb;
+       sr_receive_data_callback_t cb;
        void *user_data;
 };
 
@@ -114,7 +114,7 @@ SR_API int sr_session_dev_clear(void)
  * Add a device to the current session.
  *
  * @param dev The device to add to the current session. Must not be NULL.
*            Also, dev->plugin and dev->plugin->dev_open must not be NULL.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  */
@@ -127,13 +127,13 @@ SR_API int sr_session_dev_add(struct sr_dev *dev)
                return SR_ERR_ARG;
        }
 
-       if (!dev->plugin) {
-               sr_err("session: %s: dev->plugin was NULL", __func__);
+       if (!dev->driver) {
+               sr_err("session: %s: dev->driver was NULL", __func__);
                return SR_ERR_ARG;
        }
 
-       if (!dev->plugin->dev_open) {
-               sr_err("session: %s: dev->plugin->dev_open was NULL",
+       if (!dev->driver->dev_open) {
+               sr_err("session: %s: dev->driver->dev_open was NULL",
                       __func__);
                return SR_ERR_ARG;
        }
@@ -143,7 +143,7 @@ SR_API int sr_session_dev_add(struct sr_dev *dev)
                return SR_ERR; /* TODO: SR_ERR_BUG? */
        }
 
-       if ((ret = dev->plugin->dev_open(dev->plugin_index)) != SR_OK) {
+       if ((ret = dev->driver->dev_open(dev->driver_index)) != SR_OK) {
                sr_err("session: %s: dev_open failed (%d)", __func__, ret);
                return ret;
        }
@@ -174,21 +174,21 @@ SR_API int sr_session_datafeed_callback_clear(void)
 /**
  * Add a datafeed callback to the current session.
  *
- * @param callback Function to call when a chunk of data is received.
+ * @param cb Function to call when a chunk of data is received.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
-SR_API int sr_session_datafeed_callback_add(sr_datafeed_callback callback)
+SR_API int sr_session_datafeed_callback_add(sr_datafeed_callback_t cb)
 {
        if (!session) {
                sr_err("session: %s: session was NULL", __func__);
                return SR_ERR_BUG;
        }
 
-       /* TODO: Is 'callback' allowed to be NULL? */
+       /* TODO: Is 'cb' allowed to be NULL? */
 
        session->datafeed_callbacks =
-           g_slist_append(session->datafeed_callbacks, callback);
+           g_slist_append(session->datafeed_callbacks, cb);
 
        return SR_OK;
 }
@@ -269,15 +269,15 @@ SR_API int sr_session_start(void)
                return SR_ERR; /* TODO: SR_ERR_BUG? */
        }
 
-       /* TODO: Check plugin_index validity? */
+       /* TODO: Check driver_index validity? */
 
        sr_info("session: starting");
 
        for (l = session->devs; l; l = l->next) {
                dev = l->data;
                /* TODO: Check for dev != NULL. */
-               if ((ret = dev->plugin->dev_acquisition_start(
-                               dev->plugin_index, dev)) != SR_OK) {
+               if ((ret = dev->driver->dev_acquisition_start(
+                               dev->driver_index, dev)) != SR_OK) {
                        sr_err("session: %s: could not start an acquisition "
                               "(%d)", __func__, ret);
                        break;
@@ -352,7 +352,7 @@ SR_API int sr_session_halt(void)
  * Stop the current session.
  *
  * The current session is stopped immediately, with all acquisition sessions
- * being stopped and hardware plugins cleaned up.
+ * being stopped and hardware drivers cleaned up.
  *
  * @return SR_OK upon success, SR_ERR_BUG if no session exists.
  */
@@ -372,11 +372,11 @@ SR_API int sr_session_stop(void)
        for (l = session->devs; l; l = l->next) {
                dev = l->data;
                /* Check for dev != NULL. */
-               if (dev->plugin) {
-                       if (dev->plugin->dev_acquisition_stop)
-                               dev->plugin->dev_acquisition_stop(dev->plugin_index, dev);
-                       if (dev->plugin->cleanup)
-                               dev->plugin->cleanup();
+               if (dev->driver) {
+                       if (dev->driver->dev_acquisition_stop)
+                               dev->driver->dev_acquisition_stop(dev->driver_index, dev);
+                       if (dev->driver->cleanup)
+                               dev->driver->cleanup();
                }
        }
 
@@ -419,23 +419,23 @@ static void datafeed_dump(struct sr_datafeed_packet *packet)
  * Hardware drivers use this to send a data packet to the frontend.
  *
  * @param dev TODO.
- * @param packet TODO.
+ * @param packet The datafeed packet to send to the session bus.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.
  */
-SR_PRIV int sr_session_bus(struct sr_dev *dev,
-                          struct sr_datafeed_packet *packet)
+SR_PRIV int sr_session_send(struct sr_dev *dev,
+                           struct sr_datafeed_packet *packet)
 {
        GSList *l;
-       sr_datafeed_callback cb;
+       sr_datafeed_callback_t cb;
 
        if (!dev) {
                sr_err("session: %s: dev was NULL", __func__);
                return SR_ERR_ARG;
        }
 
-       if (!dev->plugin) {
-               sr_err("session: %s: dev->plugin was NULL", __func__);
+       if (!dev->driver) {
+               sr_err("session: %s: dev->driver was NULL", __func__);
                return SR_ERR_ARG;
        }
 
@@ -463,19 +463,19 @@ SR_PRIV int sr_session_bus(struct sr_dev *dev,
  * @param fd TODO.
  * @param events TODO.
  * @param timeout TODO.
- * @param callback TODO.
+ * @param cb TODO.
  * @param user_data TODO.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments, or
  *         SR_ERR_MALLOC upon memory allocation errors.
  */
 SR_API int sr_session_source_add(int fd, int events, int timeout,
-               sr_receive_data_callback callback, void *user_data)
+               sr_receive_data_callback_t cb, void *user_data)
 {
        struct source *new_sources, *s;
 
-       if (!callback) {
-               sr_err("session: %s: callback was NULL", __func__);
+       if (!cb) {
+               sr_err("session: %s: cb was NULL", __func__);
                return SR_ERR_ARG;
        }
 
@@ -497,7 +497,7 @@ SR_API int sr_session_source_add(int fd, int events, int timeout,
        s->fd = fd;
        s->events = events;
        s->timeout = timeout;
-       s->cb = callback;
+       s->cb = cb;
        s->user_data = user_data;
        sources = new_sources;
@@ -114,7 +114,7 @@ SR_API int sr_session_dev_clear(void)
  *
  * @param dev The device to add to the current session. Must not be NULL.
- *            Also, dev->plugin and dev->plugin->dev_open must not be NULL.
+ *            Also, dev->driver and dev->driver->dev_open must not be NULL.
  *
  * @return SR_OK upon success, SR_ERR_ARG upon invalid arguments.